# coding: utf-8

# flake8: noqa
"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from team_member_server_sdk.models.action_code import ActionCode
from team_member_server_sdk.models.action_operation import ActionOperation
from team_member_server_sdk.models.action_to_update import ActionToUpdate
from team_member_server_sdk.models.activate_team_member_request import ActivateTeamMemberRequest
from team_member_server_sdk.models.add_team_member_role_request import AddTeamMemberRoleRequest
from team_member_server_sdk.models.disable_team_member_request import DisableTeamMemberRequest
from team_member_server_sdk.models.enable_team_member_request import EnableTeamMemberRequest
from team_member_server_sdk.models.entity_settings_to_update import EntitySettingsToUpdate
from team_member_server_sdk.models.entity_type import EntityType
from team_member_server_sdk.models.http_validation_error import HTTPValidationError
from team_member_server_sdk.models.invite_team_member_request import InviteTeamMemberRequest
from team_member_server_sdk.models.location_inner import LocationInner
from team_member_server_sdk.models.portal_member_schema import PortalMemberSchema
from team_member_server_sdk.models.remove_team_member_request import RemoveTeamMemberRequest
from team_member_server_sdk.models.remove_team_member_role_request import RemoveTeamMemberRoleRequest
from team_member_server_sdk.models.resend_invitation_email_request import ResendInvitationEmailRequest
from team_member_server_sdk.models.scope_schema import ScopeSchema
from team_member_server_sdk.models.settings_operation import SettingsOperation
from team_member_server_sdk.models.team_member_access_response import TeamMemberAccessResponse
from team_member_server_sdk.models.team_member_actions_request import TeamMemberActionsRequest
from team_member_server_sdk.models.team_member_amount_request import TeamMemberAmountRequest
from team_member_server_sdk.models.team_member_request import TeamMemberRequest
from team_member_server_sdk.models.team_member_response import TeamMemberResponse
from team_member_server_sdk.models.team_member_role_response import TeamMemberRoleResponse
from team_member_server_sdk.models.team_member_role_schema import TeamMemberRoleSchema
from team_member_server_sdk.models.team_member_role_values_to_update import TeamMemberRoleValuesToUpdate
from team_member_server_sdk.models.team_member_values_to_update import TeamMemberValuesToUpdate
from team_member_server_sdk.models.update_team_member_request import UpdateTeamMemberRequest
from team_member_server_sdk.models.update_team_member_role_actions_request import UpdateTeamMemberRoleActionsRequest
from team_member_server_sdk.models.update_team_member_role_entity_settings_request import UpdateTeamMemberRoleEntitySettingsRequest
from team_member_server_sdk.models.update_team_member_role_request import UpdateTeamMemberRoleRequest
from team_member_server_sdk.models.validation_error import ValidationError
from team_member_server_sdk.models.wrapped_response_int import WrappedResponseInt
from team_member_server_sdk.models.wrapped_response_list_team_member_response import WrappedResponseListTeamMemberResponse
from team_member_server_sdk.models.wrapped_response_list_team_member_role_response import WrappedResponseListTeamMemberRoleResponse
from team_member_server_sdk.models.wrapped_response_team_member_access_response import WrappedResponseTeamMemberAccessResponse
from team_member_server_sdk.models.wrapped_response_team_member_response import WrappedResponseTeamMemberResponse
from team_member_server_sdk.models.wrapped_response_team_member_role_response import WrappedResponseTeamMemberRoleResponse



# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.team_member_access_response import TeamMemberAccessResponse  # noqa: E501

class TestTeamMemberAccessResponse(unittest.TestCase):
    """TeamMemberAccessResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TeamMemberAccessResponse:
        """Test TeamMemberAccessResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TeamMemberAccessResponse`
        """
        model = TeamMemberAccessResponse()  # noqa: E501
        if include_optional:
            return TeamMemberAccessResponse(
                portal_member_id = 56,
                team_member_role = team_member_server_sdk.models.team_member_role_schema.TeamMemberRoleSchema(
                    id = 56, 
                    title = '', 
                    enabled_at = 56, 
                    action_codes = [
                        ''
                        ], 
                    scopes = team_member_server_sdk.models.scope_schema.ScopeSchema(
                        course_ids = [
                            56
                            ], 
                        community_ids = [
                            56
                            ], ), )
            )
        else:
            return TeamMemberAccessResponse(
                portal_member_id = 56,
                team_member_role = team_member_server_sdk.models.team_member_role_schema.TeamMemberRoleSchema(
                    id = 56, 
                    title = '', 
                    enabled_at = 56, 
                    action_codes = [
                        ''
                        ], 
                    scopes = team_member_server_sdk.models.scope_schema.ScopeSchema(
                        course_ids = [
                            56
                            ], 
                        community_ids = [
                            56
                            ], ), ),
        )
        """

    def testTeamMemberAccessResponse(self):
        """Test TeamMemberAccessResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.team_member_amount_request import TeamMemberAmountRequest  # noqa: E501

class TestTeamMemberAmountRequest(unittest.TestCase):
    """TeamMemberAmountRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TeamMemberAmountRequest:
        """Test TeamMemberAmountRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TeamMemberAmountRequest`
        """
        model = TeamMemberAmountRequest()  # noqa: E501
        if include_optional:
            return TeamMemberAmountRequest(
                email = '',
                team_member_role_id = 56,
                portal_id = 56
            )
        else:
            return TeamMemberAmountRequest(
        )
        """

    def testTeamMemberAmountRequest(self):
        """Test TeamMemberAmountRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
